==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/General/streambrowser/translations/streambrowser_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>StreamBrowser</name>
    <message>
        <location filename="../streambrowser.cpp" line="33"/>
        <source>Stream Browser</source>
        <translation>Prohlížeč proudů</translation>
    </message>
    <message>
        <location filename="../streambrowser.cpp" line="35"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
</context>
<context>
    <name>StreamBrowserFactory</name>
    <message>
        <location filename="../streambrowserfactory.cpp" line="29"/>
        <source>Stream Browser Plugin</source>
        <translation>Modul prohlížeče proudů</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="50"/>
        <source>About Stream Browser Plugin</source>
        <translation>O modulu prohlížeče proudů</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="51"/>
        <source>Qmmp Stream Browser Plugin</source>
        <translation>Modul Qmmp na prohlížení proudů</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="52"/>
        <source>This plugin allows one to add stream from IceCast stream directory</source>
        <translation>Tento modul umožňuje přidat proud z adresáře proudů IceCast</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StreamWindow</name>
    <message>
        <location filename="../streamwindow.ui" line="14"/>
        <source>Stream Browser</source>
        <translation>Prohlížeč proudů</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="31"/>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="47"/>
        <source>Favorites</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="73"/>
        <source>IceCast</source>
        <translation>IceCast</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="102"/>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="109"/>
        <source>Update</source>
        <translation>Aktualizovat</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="52"/>
        <location filename="../streamwindow.cpp" line="70"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="53"/>
        <location filename="../streamwindow.cpp" line="71"/>
        <source>Genre</source>
        <translation>Žánr</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="54"/>
        <location filename="../streamwindow.cpp" line="72"/>
        <source>Bitrate</source>
        <translation>Datový tok</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="55"/>
        <location filename="../streamwindow.cpp" line="73"/>
        <source>Format</source>
        <translation>Formát</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="126"/>
        <source>&amp;Add to favorites</source>
        <translation>Přidat k &amp;oblíbeným</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="127"/>
        <source>&amp;Add to playlist</source>
        <translation>Přidat do &amp;seznamu</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="132"/>
        <source>&amp;Remove</source>
        <translation>Odst&amp;ranit</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="142"/>
        <source>Done</source>
        <translation>Hotovo</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="145"/>
        <location filename="../streamwindow.cpp" line="146"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="165"/>
        <source>Receiving</source>
        <translation>Příjímám</translation>
    </message>
</context>
</TS>

==> qmmp_1.4.3.orig.tar.bz2: qmmp-1.4.3/src/plugins/General/streambrowser/translations/streambrowser_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>EditStreamDialog</name>
    <message>
        <location filename="../editstreamdialog.ui" line="14"/>
        <source>Edit Stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="34"/>
        <source>URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="44"/>
        <source>Name:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="54"/>
        <source>Genre:</source>
        <translation>Žánr:</translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="64"/>
        <source>Bitrate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="74"/>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StreamBrowser</name>
    <message>
        <location filename="../streambrowser.cpp" line="33"/>
        <source>Add Stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streambrowser.cpp" line="35"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
</context>
<context>
    <name>StreamBrowserFactory</name>
    <message>
        <location filename="../streambrowserfactory.cpp" line="29"/>
        <source>Stream Browser Plugin</source>
        <translation>Modul prohlížeče proudů</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="50"/>
        <source>About Stream Browser Plugin</source>
        <translation>O modulu prohlížeče proudů</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="51"/>
        <source>Qmmp Stream Browser Plugin</source>
        <translation>Modul Qmmp na prohlížení proudů</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="52"/>
        <source>This plugin allows one to add stream from IceCast stream directory</source>
        <translation>Tento modul umožňuje přidat proud z adresáře proudů IceCast</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StreamWindow</name>
    <message>
        <location filename="../streamwindow.ui" line="14"/>
        <source>Stream Browser</source>
        <translation>Prohlížeč proudů</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="31"/>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="47"/>
        <source>Favorites</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="73"/>
        <source>IceCast</source>
        <translation>IceCast</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="102"/>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="109"/>
        <source>Update</source>
        <translation>Aktualizovat</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="56"/>
        <location filename="../streamwindow.cpp" line="74"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="57"/>
        <location filename="../streamwindow.cpp" line="75"/>
        <source>Genre</source>
        <translation>Žánr</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="58"/>
        <location filename="../streamwindow.cpp" line="76"/>
        <source>Bitrate</source>
        <translation>Datový tok</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="59"/>
        <location filename="../streamwindow.cpp" line="77"/>
        <source>Format</source>
        <translation>Formát</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="134"/>
        <source>&amp;Add to favorites</source>
        <translation>Přidat k &amp;oblíbeným</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="137"/>
        <source>&amp;Add to playlist</source>
        <translation>Přidat do &amp;seznamu</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="140"/>
        <source>&amp;Create</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="142"/>
        <source>&amp;Edit</source>
        <translation>Ú&amp;pravy</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="145"/>
        <source>&amp;Remove</source>
        <translation>Odst&amp;ranit</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="155"/>
        <source>Done</source>
        <translation>Hotovo</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="158"/>
        <location filename="../streamwindow.cpp" line="159"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="178"/>
        <source>Receiving</source>
        <translation>Příjímám</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="281"/>
        <source>Edit Stream</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
